@@ -48,7 +48,9 @@ STYLE_TO_ELEMENT_MAPPING = {
 }
 
 
-def partition_docx(filename: Optional[str] = None, file: Optional[IO] = None) -> List[Element]:
+def partition_docx(
+    filename: Optional[str] = None, file: Optional[IO] = None, **kwargs
+) -> List[Element]:
     """Partitions Microsoft Word Documents in .docx format into its document elements.
 
     Parameters
