@@ -2,7 +2,7 @@ from typing import IO, List, Optional
 
 import pptx
 
-from unstructured.documents.elements import Element, ListItem, NarrativeText, Text, Title
+from unstructured.documents.elements import Element, ListItem, NarrativeText, PageBreak, Text, Title
 from unstructured.partition.text_type import (
     is_possible_narrative_text,
     is_possible_title,
@@ -12,7 +12,11 @@ from unstructured.partition.text_type import (
 OPENXML_SCHEMA_NAME = "{http://schemas.openxmlformats.org/drawingml/2006/main}"
 
 
-def partition_pptx(filename: Optional[str] = None, file: Optional[IO] = None) -> List[Element]:
+def partition_pptx(
+    filename: Optional[str] = None,
+    file: Optional[IO] = None,
+    include_page_breaks: bool = True,
+) -> List[Element]:
     """Partitions Microsoft PowerPoint Documents in .pptx format into its document elements.
 
     Parameters
@@ -21,6 +25,8 @@ def partition_pptx(filename: Optional[str] = None, file: Optional[IO] = None) ->
         A string defining the target filename path.
     file
         A file-like object using "rb" mode --> open(filename, "rb").
+    include_page_breaks
+        If True, includes a PageBreak element between slides
     """
 
     if not any([filename, file]):
@@ -34,7 +40,8 @@ def partition_pptx(filename: Optional[str] = None, file: Optional[IO] = None) ->
         raise ValueError("Only one of filename or file can be specified.")
 
     elements: List[Element] = list()
-    for slide in presentation.slides:
+    num_slides = len(presentation.slides)
+    for i, slide in enumerate(presentation.slides):
         for shape in _order_shapes(slide.shapes):
             # NOTE(robinson) - we don't deal with tables yet, but so future humans can find
             # it again, here are docs on how to deal with tables. The check for tables should
@@ -58,6 +65,9 @@ def partition_pptx(filename: Optional[str] = None, file: Optional[IO] = None) ->
                 else:
                     elements.append(Text(text=text))
 
+        if include_page_breaks and i < num_slides - 1:
+            elements.append(PageBreak())
+
     return elements
 
 
