@@ -11,7 +11,7 @@ def convert_to_isd(elements: List[Text]) -> List[Dict[str, str]]:
     """Represents the document elements as an Initial Structured Document (ISD)."""
     isd: List[Dict[str, str]] = list()
     for element in elements:
-        section = dict(text=element.text, type=element.category)
+        section = element.to_dict()
         isd.append(section)
     return isd
 
